mailr4991 - /branches/N_state_model/specific_fns/n_state_model.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on February 14, 2008 - 17:24:
Author: bugman
Date: Thu Feb 14 17:24:33 2008
New Revision: 4991

URL: http://svn.gna.org/viewcvs/relax?rev=4991&view=rev
Log:
The order parameter (S_cone) for diffusion in an axially symmetric cone is 
now calculated.


Modified:
    branches/N_state_model/specific_fns/n_state_model.py

Modified: branches/N_state_model/specific_fns/n_state_model.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/N_state_model/specific_fns/n_state_model.py?rev=4991&r1=4990&r2=4991&view=diff
==============================================================================
--- branches/N_state_model/specific_fns/n_state_model.py (original)
+++ branches/N_state_model/specific_fns/n_state_model.py Thu Feb 14 17:24:33 
2008
@@ -21,7 +21,7 @@
 
###############################################################################
 
 # Python module imports.
-from math import acos, pi
+from math import acos, cos, pi
 from numpy import array, dot, float64, zeros
 from numpy.linalg import norm
 from re import search
@@ -149,8 +149,9 @@
         # The cone angle for diffusion on an axially symmetric cone.
         cdp.diff_on_cone_theta = acos(len_red)
 
         # The cone angle for diffusion in an axially symmetric cone.
symmetric cone.
         cdp.diff_in_cone_theta = acos(2.*len_red - 1.)
+        cdp.S_diff_in_cone = cos(cdp.diff_in_cone_theta) * (1 + 
cos(cdp.diff_in_cone_theta)) / 2.0
 
         # Print out.
         print "\nThe pivot point of the domain motions is:\n" + 
`cdp.pivot_point` + "\n"
@@ -161,6 +162,7 @@
         print "The length reduction is:\n" + `len_red` + "\n"
         print "The cone angle for diffusion on an axially symmetric cone 
is:\n%.5f rad (%.5f deg)\n" % (cdp.diff_on_cone_theta, cdp.diff_on_cone_theta 
/ (2*pi) *360.)
         print "The cone angle for diffusion in an axially symmetric cone 
is:\n%.5f rad (%.5f deg)\n" % (cdp.diff_in_cone_theta, cdp.diff_in_cone_theta 
/ (2*pi) *360.)
+        print "The order parameter (S_cone) for diffusion in an axially 
symmetric cone is:\nS_cone = %.5f\nS^2 = %.5f\n" % (cdp.S_diff_in_cone, 
cdp.S_diff_in_cone**2)
 
@@ -149,8 +149,9 @@
         cdp.diff_on_cone_theta = acos(len_red)
 
-        # The cone angle for diffusion in an axially symmetric cone.
+        # The cone angle and order parameter for diffusion in an axially 
symmetric cone.
         cdp.diff_in_cone_theta = acos(2.*len_red - 1.)
 
     def default_value(self, param):




Related Messages


Powered by MHonArc, Updated Fri Feb 15 09:20:37 2008